@@ -161,13 +161,13 @@ def main(args=None):
         if len(geom) > 0:
 # C.1) Export to netcdf
 # C.1.i) Netcdf filename
-            try:
-                fname = nc_name(metadata[i], prod_id = ids[i], wave = wave[i], 
-                                ver = __version__)
-            except Exception as e:
-                logger.error("Error while creating the netcdf filename ")
-                sys.exit(9)  
-            logger.info("       Netcdf filename succesfully created ")
+            # try:
+            fname = nc_name(metadata[i], prod_id = ids[i], wave = wave[i], 
+                            ver = __version__)
+            # except Exception as e:
+                # logger.error("Error while creating the netcdf filename ")
+                # sys.exit(9)  
+            # logger.info("       Netcdf filename succesfully created ")
             
 # C.1.ii) Netcdf file        
             try:
