@@ -69,12 +69,6 @@ def export_nc(geom, metadata, alpha, wave, thres, fname, dir_out):
     return(geom_dts)
 
 def nc_name(metadata, prod_id, wave, ver):
-    
-    parser = configparser.ConfigParser()
-    parser.read('./default.ini')
-    
-    app = parser._sections['info']['name']
-    ver = parser._sections['info']['version']
 
     ms_id = metadata['measurement_ID']
     
@@ -89,6 +83,6 @@ def nc_name(metadata, prod_id, wave, ver):
     stop_t = parse_date.parse(metadata['measurement_stop_datetime'])\
         .strftime('%Y%m%d%H%M')
         
-    fname = f'{st_id}_{wave}_{prod_id}_{start_t}_{stop_t}_{ms_id}_{app}_v{ver}.nc'
+    fname = f'{st_id}_{wave}_{prod_id}_{start_t}_{stop_t}_{ms_id}_ltool_v{ver}.nc'
 
     return(fname)
\ No newline at end of file
